aboutsummaryrefslogtreecommitdiffstats
path: root/cmd/utils
diff options
context:
space:
mode:
authorWei-Ning Huang <w@dexon.org>2018-10-24 18:59:48 +0800
committerWei-Ning Huang <w@dexon.org>2018-12-19 20:54:27 +0800
commit46de04d42cd3292bad26133a1d00905e342773dd (patch)
tree274cf9398e1e905235e7c464b1d75d8b78ef364c /cmd/utils
parentedae2e0b2f898abfe64e4b7998103a8a67cce914 (diff)
downloaddexon-46de04d42cd3292bad26133a1d00905e342773dd.tar
dexon-46de04d42cd3292bad26133a1d00905e342773dd.tar.gz
dexon-46de04d42cd3292bad26133a1d00905e342773dd.tar.bz2
dexon-46de04d42cd3292bad26133a1d00905e342773dd.tar.lz
dexon-46de04d42cd3292bad26133a1d00905e342773dd.tar.xz
dexon-46de04d42cd3292bad26133a1d00905e342773dd.tar.zst
dexon-46de04d42cd3292bad26133a1d00905e342773dd.zip
Rename geth -> gdex and fix Dockerfile
Diffstat (limited to 'cmd/utils')
-rw-r--r--cmd/utils/flags.go10
1 files changed, 5 insertions, 5 deletions
diff --git a/cmd/utils/flags.go b/cmd/utils/flags.go
index 5a6a6476f..c7a1b77de 100644
--- a/cmd/utils/flags.go
+++ b/cmd/utils/flags.go
@@ -603,7 +603,7 @@ var (
MetricsInfluxDBDatabaseFlag = cli.StringFlag{
Name: "metrics.influxdb.database",
Usage: "InfluxDB database name to push reported metrics to",
- Value: "geth",
+ Value: "gdex",
}
MetricsInfluxDBUsernameFlag = cli.StringFlag{
Name: "metrics.influxdb.username",
@@ -851,7 +851,7 @@ func MakeAddress(ks *keystore.KeyStore, account string) (accounts.Account, error
log.Warn("-------------------------------------------------------------------")
log.Warn("Referring to accounts by order in the keystore folder is dangerous!")
log.Warn("This functionality is deprecated and will be removed in the future!")
- log.Warn("Please use explicit addresses! (can search via `geth account list`)")
+ log.Warn("Please use explicit addresses! (can search via `gdex account list`)")
log.Warn("-------------------------------------------------------------------")
accs := ks.Accounts()
@@ -1317,7 +1317,7 @@ func SetupMetrics(ctx *cli.Context) {
if enableExport {
log.Info("Enabling metrics export to InfluxDB")
- go influxdb.InfluxDBWithTags(metrics.DefaultRegistry, 10*time.Second, endpoint, database, username, password, "geth.", map[string]string{
+ go influxdb.InfluxDBWithTags(metrics.DefaultRegistry, 10*time.Second, endpoint, database, username, password, "gdex.", map[string]string{
"host": hosttag,
})
}
@@ -1420,11 +1420,11 @@ func MakeConsolePreloads(ctx *cli.Context) []string {
// This is a temporary function used for migrating old command/flags to the
// new format.
//
// e.g. geth account new --keystore /tmp/mykeystore --lightkdf
//
// is equivalent after calling this method with:
//
// geth --keystore /tmp/mykeystore --lightkdf account new
//
// This allows the use of the existing configuration functionality.
// When all flags are migrated this function can be removed and the existing
@@ -1420,11 +1420,11 @@ func MakeConsolePreloads(ctx *cli.Context) []string {
// new format.
//
-// e.g. geth account new --keystore /tmp/mykeystore --lightkdf
+// e.g. gdex account new --keystore /tmp/mykeystore --lightkdf
//
// is equivalent after calling this method with:
@@ -1420,11 +1420,11 @@ func MakeConsolePreloads(ctx *cli.Context) []string {
// is equivalent after calling this method with:
//
-// geth --keystore /tmp/mykeystore --lightkdf account new
+// gdex --keystore /tmp/mykeystore --lightkdf account new
//
// This allows the use of the existing configuration functionality.